use warnings;
use strict;

# Please note: This file is generated when munin is built.

package Munin::Common::Defaults;

use English qw(-no_match_vars);
use File::Basename qw(dirname);

# This file's package variables are changed during the build process.
# This variable makes only sense in development environment
my $COMPONENT_ROOT = dirname(__FILE__) . '/../../..';

our $DROPDOWNLIMIT = 1;

our $MUNIN_CONFDIR    = '/etc/munin';
# our $MUNIN_BINDIR     = '';
# our $MUNIN_SBINDIR    = '';
# our $MUNIN_DOCDIR     = '';
our $MUNIN_LIBDIR     = '/usr/share/munin';
our $MUNIN_HTMLDIR    = '/var/www/munin';
# our $MUNIN_CGIDIR     = '';
our $MUNIN_CGITMPDIR  = '/var/cache/munin';
our $MUNIN_DBDIR      = '/var/lib/munin';
our $MUNIN_PLUGSTATE  = '/var/lib/munin-node/plugin-state';
our $MUNIN_SPOOLDIR   = '/var/spool/munin';
# our $MUNIN_MANDIR     = '';
our $MUNIN_LOGDIR     = '/var/log/munin';
our $MUNIN_STATEDIR   = '/var/run/munin';
our $MUNIN_USER       = $OSNAME eq 'MSWin32' ? '' : getpwuid $EUID;
our $MUNIN_GROUP      = $OSNAME eq 'MSWin32' ? '' : getgrgid $EGID;
our $MUNIN_PLUGINUSER = $OSNAME eq 'MSWin32' ? '' : getpwuid $EUID;
our $MUNIN_VERSION    = '2.999.11';
our $MUNIN_PERL       = '/usr/bin/perl';
# our $MUNIN_PERLLIB    = '';
# our $MUNIN_GOODSH     = '';
# our $MUNIN_BASH       = '';
# our $MUNIN_PYTHON     = '';
# our $MUNIN_RUBY       = '';
# our $MUNIN_OSTYPE     = '';
# our $MUNIN_HOSTNAME   = '';
our $MUNIN_HASSETR    = '';
sub get_defaults {
    my ($class) = @_;


    no strict 'refs'; ## no critic qw( ProhibitNoStrict )
    my $defaults = {};
    for my $g ( keys %{"Munin::Common::Defaults::"} ) {
        next unless $g =~ /MUNIN_/;
        $defaults->{$g} = ${ *$g{'SCALAR'} };
    }

    return $defaults;
}

sub export_to_environment {
    my ($class) = @_;

    my %defaults = %{ $class->get_defaults() };
    while ( my ( $k, $v ) = each %defaults ) {
        $ENV{$k} = $v;
    }

    return;
}

sub print_as_sed_substitutions {
    my ($class) = @_;

    my %defaults = %{ $class->get_defaults() };
    while ( my ( $k, $v ) = each %defaults ) {
        $k =~ /MUNIN_(.*)/;
        print("s#@@" . $1 . "@@#$v#;");
    }

    return;
}

1;

__END__


=head1 NAME

Munin::Common::Defaults - Default values defined by installation
scripts.


=head1 PACKAGE VARIABLES

See L<http://munin-monitoring.org/wiki/MuninInstallProcedure> for
more information on the variables provided by this package.


=head1 METHODS

=over

=item B<get_defaults>

  \%defaults = $class->get_defaults()

Returns all the package variables as key value pairs in a hash.

=item B<export_to_environment>

  $class = $class->export_to_environment()

Export all the package variables to the environment.

=item B<print_as_sed_substitutions>

  $class->print_as_sed_substitutions()

Output an expression suitable for "sed". This expression can be used to
substitute placeholders (e.g. "@@SPOOLDIR") in munin's source files
during an installation procedure.

=back

